@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sa Mar 25 2006
     copyright            : (C) 2006 by Christian Hilgers
-    email                : christian@hilgers.ag
+    email                : christian@havp.org
  ***************************************************************************/
 
 /***************************************************************************
